@@ -1,11 +1,13 @@
 #! /bin/sh
 
+rm -f config.cache
+
 echo aclocal...
 (aclocal --version) < /dev/null > /dev/null 2>&1 || {
     echo aclocal not found
     exit 1
 }
-aclocal
+aclocal $ACLOCAL_FLAGS
 
 echo autoheader...
 (autoheader --version) < /dev/null > /dev/null 2>&1 || {
