@@ -4,6 +4,7 @@
 
 #include <iostream>
 #include <string>
+#include <sstream>
 
 #include <cassert>
 
@@ -32,24 +33,36 @@ int main( int argc, char ** argv)
 
   config.getCmdline( argc, argv);
   config.getEnv( "TEST_");
-  config.readFromFile( "conf.cfg");
+  assert(config.readFromFile( std::string(SRCDIR) + "/conf.cfg"));
   config.setItem( "tcp", "port", 6700, varconf::GLOBAL);
   config.setItem( "tcp", "v6port", 6700, varconf::USER);
   config.setItem( "console", "colours", "plenty", varconf::INSTANCE);
   config.setItem( "console", "speed", "fast", varconf::USER);
 
+  assert(config.find("tcp", "port"));
+  assert(config.find("console", "enabled"));
   assert(config.getItem("tcp", "port")->scope() == varconf::GLOBAL);
+  //Default scope for read files are USER
+  assert(config.getItem("console", "enabled")->scope() == varconf::USER);
 
   std::cout << "\nEnter sample configuration data to test parseStream() method.\n";
 
+  std::stringstream ss;
+  ss << "[general]"<< std::endl;
+  ss << "setting = true"<< std::endl;
+  ss << "emptyrightbeforeeof = ";
+
   try {
-    config.parseStream( std::cin, varconf::USER);
+    config.parseStream( ss, varconf::USER);
   }
   catch ( varconf::ParseError p) {
-    std::cout << "\nError while parsing from standard input stream.\n";
+    std::cout << "\nError while parsing from input stream.\n";
     std::cout << p;
   }
 
+  assert(config.find("general", "setting"));
+  assert(config.find("general", "emptyrightbeforeeof"));
+
   config.writeToFile( "conf2.cfg");
   
   std::cout << "\nFile configuration data:\n"
