@@ -1,6 +1,7 @@
 /*
  *  parse_error.h - interface for parse error handling class.
  *  Copyright (C) 2001, Stefanus Du Toit, Joseph Zupko
+ *            (C) 2004 Alistair Riddoch
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -26,12 +27,13 @@
 #ifndef VARCONF_PARSEERROR_H
 #define VARCONF_PARSEERROR_H
 
+#include <varconf/varconf_defs.h>
 #include <iostream>
 #include <string>
 
 namespace varconf {
 
-class ParseError {
+class VARCONF_API ParseError {
 public:
   ParseError() {}
   ParseError(const ParseError& p);
@@ -48,6 +50,8 @@ private:
   int m_line, m_col;
 };
 
+VARCONF_API std::ostream& operator<<(std::ostream& os, const ParseError& p);
+
 } // namespace varconf
 
 #endif
